summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--common/usb_pd_protocol.c8
1 files changed, 7 insertions, 1 deletions
diff --git a/common/usb_pd_protocol.c b/common/usb_pd_protocol.c
index 8ca0bbb6fc..4bf8e600e0 100644
--- a/common/usb_pd_protocol.c
+++ b/common/usb_pd_protocol.c
@@ -2649,8 +2649,14 @@ void pd_task(void *u)
pd_init_tasks();
#endif
/* Ensure the power supply is in the default state */
pd_power_supply_reset(port);
+#ifdef CONFIG_USBC_VCONN
+ set_vconn(port, 0);
+#endif
/* Initialize TCPM driver and wait for TCPC to be ready */
res = reset_device_and_notify(port);
@@ -2649,8 +2649,14 @@ void pd_task(void *u)
pd_init_tasks();
#endif
- /* Ensure the power supply is in the default state */
+ /*
+ * Ensure the power supply is in the default state and ensure we are not
+ * sourcing Vconn
+ */
pd_power_supply_reset(port);